# Reference
::: kmService.ProjectionResponse
    options:
      show_root_heading: true
      show_source: false

::: kmService.ProjectionInputResponse
    options:
      show_root_heading: true
      show_source: false

